@@ -50,6 +50,7 @@
 #include "xfw-marshal.h"
 #include "xfw-screen.h"
 #include "xfw-window-private.h"
+#include "libxfce4windowing-visibility.h"
 
 #define XFW_WINDOW_GET_PRIVATE(window) ((XfwWindowPrivate *)xfw_window_get_instance_private(window))
 
@@ -767,11 +768,11 @@ xfw_window_get_application(XfwWindow *window) {
 }
 
 gboolean
-xfw_window_activate(XfwWindow *window, guint64 event_timestamp, GError **error) {
+xfw_window_activate(XfwWindow *window, XfwSeat *seat, guint64 event_timestamp, GError **error) {
     XfwWindowClass *klass;
     g_return_val_if_fail(XFW_IS_WINDOW(window), FALSE);
     klass = XFW_WINDOW_GET_CLASS(window);
-    return (*klass->activate)(window, event_timestamp, error);
+    return (*klass->activate)(window, seat, event_timestamp, error);
 }
 
 gboolean
@@ -896,3 +897,6 @@ _xfw_window_invalidate_icon(XfwWindow *window) {
     priv->icon_size = 0;
     priv->icon_scale = 0;
 }
+
+#define __XFW_WINDOW_C__
+#include <libxfce4windowing-visibility.c>
